==> ringtoned_0.2.5-0.tar.gz: ringtoned-0.2.5/per-contact/lib/ringtone.h <==
/*
 * Copyright (C) 2010 Collabora Ltd.
 *   @author Marco Barisione <marco.barisione@collabora.co.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef __PCR_RINGTONE_H__
#define __PCR_RINGTONE_H__

#include <glib.h>
#include "i18n.h"


G_BEGIN_DECLS

#define PCR_RINGTONE_SILENT  ""
#define PCR_RINGTONE_DEFAULT NULL

#define PCR_RINGTONE_SILENT_DISPLAY_NAME  N_("Silent")
#define PCR_RINGTONE_DEFAULT_DISPLAY_NAME N_("Default")

typedef enum
{
    PCR_SPECIAL_CONTACT_UNKNOWN,
    PCR_SPECIAL_CONTACT_ANONYMOUS,
} PCRSpecialContact;

gboolean    pcr_ringtone_equal          (const gchar    *ringtone1,
                                         const gchar    *ringtone2);
gboolean    pcr_ringtone_is_default     (const gchar    *ringtone);
gboolean    pcr_ringtone_is_silent      (const gchar    *ringtone);

G_END_DECLS

#endif

==> ringtoned_1.0.3-0.tar.gz: ringtoned-1.0.3/per-contact/lib/ringtone.h <==
/*
 * Copyright (C) 2010 Collabora Ltd.
 *   @author Marco Barisione <marco.barisione@collabora.co.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef __PCR_RINGTONE_H__
#define __PCR_RINGTONE_H__

#include <glib.h>
#include "i18n.h"


G_BEGIN_DECLS

#define PCR_RINGTONE_SILENT  ""
#define PCR_RINGTONE_DEFAULT NULL

/* Note for translators: this refers to ringtone */
#define PCR_RINGTONE_SILENT_DISPLAY_NAME  N_("Silent")
/* Note for translators: this refers to ringtone */
#define PCR_RINGTONE_DEFAULT_DISPLAY_NAME N_("Default")

typedef enum
{
    PCR_SPECIAL_CONTACT_UNKNOWN,
    PCR_SPECIAL_CONTACT_ANONYMOUS,
} PCRSpecialContact;

gboolean    pcr_ringtone_equal          (const gchar    *ringtone1,
                                         const gchar    *ringtone2);
gboolean    pcr_ringtone_is_default     (const gchar    *ringtone);
gboolean    pcr_ringtone_is_silent      (const gchar    *ringtone);

G_END_DECLS

#endif
